@@ -10,15 +10,14 @@ an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express o
 specific language governing permissions and limitations under the License.
 """
 
-
 from . import Request
 from .exceptions import AuthFailedException
 
 
-def allow_or_raise_auth_failed(iam, system, subject, action, resources, environment=None):
+def allow_or_raise_auth_failed(iam, system, subject, action, resources, environment=None, cache=False):
     request = Request(system, subject, action, resources, environment)
 
-    allowed = iam.is_allowed(request)
+    allowed = iam.is_allowed_with_cache(request) if cache else iam.is_allowed(request)
 
     if not allowed:
         raise AuthFailedException(system, subject, action, resources)
